@@ -1,8 +1,9 @@
 //===-- DOTGraphTraitsPass.h - Print/View dotty graphs-----------*- C++ -*-===//
 //
-// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
-// See https://llvm.org/LICENSE.txt for license information.
-// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
+//                     The LLVM Compiler Infrastructure
+//
+// This file is distributed under the University of Illinois Open Source
+// License. See LICENSE.TXT for details.
 //
 //===----------------------------------------------------------------------===//
 //
@@ -14,10 +15,12 @@
 #define LLVM_ANALYSIS_DOTGRAPHTRAITSPASS_H
 
 #include "llvm/Analysis/CFGPrinter.h"
+#include "llvm/Pass.h"
+#include "llvm/Support/FileSystem.h"
 
 namespace llvm {
 
-/// Default traits class for extracting a graph from an analysis pass.
+/// \brief Default traits class for extracting a graph from an analysis pass.
 ///
 /// This assumes that 'GraphT' is 'AnalysisT *' and so just passes it through.
 template <typename AnalysisT, typename GraphT = AnalysisT *>
@@ -27,29 +30,14 @@ struct DefaultAnalysisGraphTraits {
 
 template <
     typename AnalysisT, bool IsSimple, typename GraphT = AnalysisT *,
-    typename AnalysisGraphTraitsT = DefaultAnalysisGraphTraits<AnalysisT, GraphT> >
+    typename AnalysisGraphTraitsT = DefaultAnalysisGraphTraits<AnalysisT> >
 class DOTGraphTraitsViewer : public FunctionPass {
 public:
   DOTGraphTraitsViewer(StringRef GraphName, char &ID)
       : FunctionPass(ID), Name(GraphName) {}
 
-  /// Return true if this function should be processed.
-  ///
-  /// An implementation of this class my override this function to indicate that
-  /// only certain functions should be viewed.
-  ///
-  /// @param Analysis The current analysis result for this function.
-  virtual bool processFunction(Function &F, AnalysisT &Analysis) {
-    return true;
-  }
-
   bool runOnFunction(Function &F) override {
-    auto &Analysis = getAnalysis<AnalysisT>();
-
-    if (!processFunction(F, Analysis))
-      return false;
-
-    GraphT Graph = AnalysisGraphTraitsT::getGraph(&Analysis);
+    GraphT Graph = AnalysisGraphTraitsT::getGraph(&getAnalysis<AnalysisT>());
     std::string GraphName = DOTGraphTraits<GraphT>::getGraphName(Graph);
     std::string Title = GraphName + " for '" + F.getName().str() + "' function";
 
@@ -69,39 +57,24 @@ private:
 
 template <
     typename AnalysisT, bool IsSimple, typename GraphT = AnalysisT *,
-    typename AnalysisGraphTraitsT = DefaultAnalysisGraphTraits<AnalysisT, GraphT> >
+    typename AnalysisGraphTraitsT = DefaultAnalysisGraphTraits<AnalysisT> >
 class DOTGraphTraitsPrinter : public FunctionPass {
 public:
   DOTGraphTraitsPrinter(StringRef GraphName, char &ID)
       : FunctionPass(ID), Name(GraphName) {}
 
-  /// Return true if this function should be processed.
-  ///
-  /// An implementation of this class my override this function to indicate that
-  /// only certain functions should be printed.
-  ///
-  /// @param Analysis The current analysis result for this function.
-  virtual bool processFunction(Function &F, AnalysisT &Analysis) {
-    return true;
-  }
-
   bool runOnFunction(Function &F) override {
-    auto &Analysis = getAnalysis<AnalysisT>();
-
-    if (!processFunction(F, Analysis))
-      return false;
-
-    GraphT Graph = AnalysisGraphTraitsT::getGraph(&Analysis);
+    GraphT Graph = AnalysisGraphTraitsT::getGraph(&getAnalysis<AnalysisT>());
     std::string Filename = Name + "." + F.getName().str() + ".dot";
-    std::error_code EC;
+    std::string ErrorInfo;
 
     errs() << "Writing '" << Filename << "'...";
 
-    raw_fd_ostream File(Filename, EC, sys::fs::OF_TextWithCRLF);
+    raw_fd_ostream File(Filename.c_str(), ErrorInfo, sys::fs::F_Text);
     std::string GraphName = DOTGraphTraits<GraphT>::getGraphName(Graph);
     std::string Title = GraphName + " for '" + F.getName().str() + "' function";
 
-    if (!EC)
+    if (ErrorInfo.empty())
       WriteGraph(File, Graph, IsSimple, Title);
     else
       errs() << "  error opening file for writing!";
@@ -121,7 +94,7 @@ private:
 
 template <
     typename AnalysisT, bool IsSimple, typename GraphT = AnalysisT *,
-    typename AnalysisGraphTraitsT = DefaultAnalysisGraphTraits<AnalysisT, GraphT> >
+    typename AnalysisGraphTraitsT = DefaultAnalysisGraphTraits<AnalysisT> >
 class DOTGraphTraitsModuleViewer : public ModulePass {
 public:
   DOTGraphTraitsModuleViewer(StringRef GraphName, char &ID)
@@ -147,7 +120,7 @@ private:
 
 template <
     typename AnalysisT, bool IsSimple, typename GraphT = AnalysisT *,
-    typename AnalysisGraphTraitsT = DefaultAnalysisGraphTraits<AnalysisT, GraphT> >
+    typename AnalysisGraphTraitsT = DefaultAnalysisGraphTraits<AnalysisT> >
 class DOTGraphTraitsModulePrinter : public ModulePass {
 public:
   DOTGraphTraitsModulePrinter(StringRef GraphName, char &ID)
@@ -156,14 +129,14 @@ public:
   bool runOnModule(Module &M) override {
     GraphT Graph = AnalysisGraphTraitsT::getGraph(&getAnalysis<AnalysisT>());
     std::string Filename = Name + ".dot";
-    std::error_code EC;
+    std::string ErrorInfo;
 
     errs() << "Writing '" << Filename << "'...";
 
-    raw_fd_ostream File(Filename, EC, sys::fs::OF_TextWithCRLF);
+    raw_fd_ostream File(Filename.c_str(), ErrorInfo, sys::fs::F_Text);
     std::string Title = DOTGraphTraits<GraphT>::getGraphName(Graph);
 
-    if (!EC)
+    if (ErrorInfo.empty())
       WriteGraph(File, Graph, IsSimple, Title);
     else
       errs() << "  error opening file for writing!";
@@ -181,25 +154,6 @@ private:
   std::string Name;
 };
 
-template <typename GraphT>
-void WriteDOTGraphToFile(Function &F, GraphT &&Graph,
-                         std::string FileNamePrefix, bool IsSimple) {
-  std::string Filename = FileNamePrefix + "." + F.getName().str() + ".dot";
-  std::error_code EC;
-
-  errs() << "Writing '" << Filename << "'...";
-
-  raw_fd_ostream File(Filename, EC, sys::fs::OF_TextWithCRLF);
-  std::string GraphName = DOTGraphTraits<GraphT>::getGraphName(Graph);
-  std::string Title = GraphName + " for '" + F.getName().str() + "' function";
-
-  if (!EC)
-    WriteGraph(File, Graph, IsSimple, Title);
-  else
-    errs() << "  error opening file for writing!";
-  errs() << "\n";
-}
-
 } // end namespace llvm
 
 #endif
